@@ -7,8 +7,8 @@ import unittest
 
 import pygame
 
-from src.yadraw_yakovkinii import logging_config
-import src as yd
+from src.yadraw import logging_config
+import src.yadraw.yadraw as yd
 
 logging_config.init()
 
